# enumx
An extended enum for python.
Publish Steps: <https://builtin.com/data-science/how-to-publish-python-code-pypi>
1. `python -m build`
2. `python -m twine upload --repository PyPI dist/*` or `py -m twine upload --skip-existing dist/*`
